==> haskell-hslua-core-2.3.2-27.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-core
version:              2.3.2
visibility:           public
id:                   hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
key:                  hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  0282f33a0119327f5812449807b5e525
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Debug,
    HsLua.Core.Error, HsLua.Core.Package, HsLua.Core.Run,
    HsLua.Core.Trace, HsLua.Core.Types, HsLua.Core.Unsafe,
    HsLua.Core.Userdata, HsLua.Core.Utf8,
    Lua from lua-2.3.3-8SYrA1CAYT85bngYHR6FzJ:Lua

hidden-modules:
    HsLua.Core.Auxiliary HsLua.Core.Primary HsLua.Core.Warn

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
depends:
    base-4.18.2.1 bytestring-0.11.5.3 exceptions-0.10.7
    lua-2.3.3-8SYrA1CAYT85bngYHR6FzJ mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-core-2.3.2-28-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-core
version:              2.3.2
visibility:           public
id:                   hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
key:                  hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Bindings to Lua, an embeddable scripting language
description:
    Wrappers and helpers to bridge Haskell and
    <https://www.lua.org/ Lua>.

    It builds upon the /lua/ package, which allows to bundle
    a Lua interpreter with a Haskell program.

category:             Foreign
abi:                  26579aaa5b831c5d3118689cfb410a55
exposed:              True
exposed-modules:
    HsLua.Core, HsLua.Core.Closures, HsLua.Core.Debug,
    HsLua.Core.Error, HsLua.Core.Package, HsLua.Core.Run,
    HsLua.Core.Trace, HsLua.Core.Types, HsLua.Core.Unsafe,
    HsLua.Core.Userdata, HsLua.Core.Utf8,
    Lua from lua-2.3.3-DlJXYaKcRYH9BfYMQSRTd9:Lua

hidden-modules:
    HsLua.Core.Auxiliary HsLua.Core.Primary HsLua.Core.Warn

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-core-2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-core
hs-libraries:         HShslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
depends:
    base-4.18.2.1 bytestring-0.11.5.3 exceptions-0.10.7
    lua-2.3.3-DlJXYaKcRYH9BfYMQSRTd9 mtl-2.3.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-core/html/hslua-core.haddock
haddock-html:         /usr/share/doc/haskell-hslua-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
